pub struct MergeError {
kind: MergeErrorKind,
}Expand description
Error produced while merging a chunk into the running state.
Fields
kind: MergeErrorKindImplementations
Sourceimpl MergeError
impl MergeError
const fn zero_iterations() -> Self
const fn chunk_index_out_of_range(index: u32, total: u32) -> Self
const fn bucket_param_mismatch() -> Self
const fn dictionary_label_conflict(target_id: u32) -> Self
Sourcepub const fn is_zero_iterations(&self) -> bool
pub const fn is_zero_iterations(&self) -> bool
Returns whether the chunk reported zero iterations.
Sourcepub const fn chunk_index_range(&self) -> Option<(u32, u32)>
pub const fn chunk_index_range(&self) -> Option<(u32, u32)>
Returns the invalid chunk index and configured chunk total, when applicable.
Sourcepub const fn is_bucket_param_mismatch(&self) -> bool
pub const fn is_bucket_param_mismatch(&self) -> bool
Returns whether the chunk and running state use different bucket sizes.
Sourcepub const fn conflicting_target_id(&self) -> Option<u32>
pub const fn conflicting_target_id(&self) -> Option<u32>
Returns the conflicting target identifier, when applicable.